==> staphb_toolkit-1.0.3.tar.gz: staphb_toolkit-1.0.3/staphb_toolkit/core/update_app.py <==
import os, sys
from shutil import which
import re
import subprocess as sub
import shlex

#selfupdate check file
selfupdate_status = os.path.join(os.path.abspath(os.path.dirname(os.path.realpath(__file__))),'selfupdate')

def toggle_updater(update):
    if update:
        if not os.path.exists(selfupdate_status):
            cmd = "touch " + selfupdate_status
            sub.Popen(shlex.split(cmd)).wait()
            print('Auto-updates on')
    else:
        if os.path.exists(selfupdate_status):
            cmd = "rm " + selfupdate_status
            sub.Popen(shlex.split(cmd)).wait()
            print('Auto-updates off')

def check_update_status():
    return os.path.exists(selfupdate_status)

def check_for_updates():
    #regular expressing for checking python version
    re_pattern = r"python\s3.[6-9]|python\s3.[0-9]{2,}"
    cmd = ''
    #Determine pip command version
    if which('pip'):
        #get python version pip is using
        output = sub.check_output(['pip','-V']).decode('utf-8').strip()
        re_obj = re.search(re_pattern,fr"{output}")
        if re_obj:
            cmd = 'pip'
    if which('pip3') and not cmd:
        #get python version pip3 is using
        output = sub.check_output(['pip3','-V']).decode('utf-8')
        re_obj = re.search(re_pattern,fr"{output}")
        if re_obj:
            cmd = 'pip3'

    #check if we have a pip command
    if not cmd:
        print("Cannot find pip for python 3.6 or greater...")
        sys.exit(1)

    #run pip update
    cmd = cmd + " install staphb-toolkit-kflorek --upgrade"
    print("Checking for updates...")
    sub.Popen(shlex.split(cmd),stdout=sub.DEVNULL,stderr=sub.STDOUT).wait()
    print("Done.")

==> staphb_toolkit-1.0.5.tar.gz: staphb_toolkit-1.0.5/staphb_toolkit/core/update_app.py <==
import os, sys
from shutil import which
import re
import subprocess as sub
import shlex

#selfupdate check file
selfupdate_status = os.path.join(os.path.abspath(os.path.dirname(os.path.realpath(__file__))),'selfupdate')

def toggle_updater(update):
    if update:
        if not os.path.exists(selfupdate_status):
            cmd = "touch " + selfupdate_status
            sub.Popen(shlex.split(cmd)).wait()
            print('Auto-updates on')
    else:
        if os.path.exists(selfupdate_status):
            cmd = "rm " + selfupdate_status
            sub.Popen(shlex.split(cmd)).wait()
            print('Auto-updates off')

def check_update_status():
    return os.path.exists(selfupdate_status)

def check_for_updates():
    #regular expressing for checking python version
    re_pattern = r"python\s3.[6-9]|python\s3.[0-9]{2,}"
    cmd = ''
    #Determine pip command version
    if which('pip'):
        #get python version pip is using
        output = sub.check_output(['pip','-V']).decode('utf-8').strip()
        re_obj = re.search(re_pattern,fr"{output}")
        if re_obj:
            cmd = 'pip'
    if which('pip3') and not cmd:
        #get python version pip3 is using
        output = sub.check_output(['pip3','-V']).decode('utf-8')
        re_obj = re.search(re_pattern,fr"{output}")
        if re_obj:
            cmd = 'pip3'

    #check if we have a pip command
    if not cmd:
        print("Cannot find pip for python 3.6 or greater...")
        sys.exit(1)

    #run pip update
    cmd = cmd + " install staphb-toolkit --upgrade"
    print("Checking for updates...")
    sub.Popen(shlex.split(cmd),stdout=sub.DEVNULL,stderr=sub.STDOUT).wait()
    print("Done.")
